/* generated using openapi-typescript-codegen -- do not edit */
/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { AnonymizedWorkflowExecution } from '../models/AnonymizedWorkflowExecution';
import type { OwnershipTransferRequestIn } from '../models/OwnershipTransferRequestIn';
import type { OwnershipTransferRequestOut } from '../models/OwnershipTransferRequestOut';
import type { WorkflowIn } from '../models/WorkflowIn';
import type { WorkflowOut } from '../models/WorkflowOut';
import type { WorkflowStatistic } from '../models/WorkflowStatistic';
import type { WorkflowUpdate } from '../models/WorkflowUpdate';
import type { WorkflowVersion } from '../models/WorkflowVersion';
import type { WorkflowVersionStatus } from '../models/WorkflowVersionStatus';
import type { CancelablePromise } from '../core/CancelablePromise';
import { OpenAPI } from '../core/OpenAPI';
import { request as __request } from '../core/request';
export class WorkflowService {
    /**
     * Create a new workflow
     * Create a new workflow.
     *
     * For private Gitlab repositories, a Project Access Token with the role Reporter and scope `read_api` is needed.
     *
     * For private GitHub repositories, a Personal Access Token (classic) with scope `repo` is needed.
     *
     * Permission `workflow:create` required.
     * @param requestBody
     * @returns WorkflowOut Successful Response
     * @throws ApiError
     */
    public static workflowCreateWorkflow(
        requestBody: WorkflowIn,
    ): CancelablePromise<WorkflowOut> {
        return __request(OpenAPI, {
            method: 'POST',
            url: '/workflows',
            body: requestBody,
            mediaType: 'application/json',
            errors: {
                400: `Error decoding JWT Token`,
                401: `Not Authenticated`,
                403: `Not Authorized`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }
    /**
     * List workflows
     * List all workflows.
     *
     * Permission `workflow:list` required.
     * @param nameSubstring Filter workflows by a substring in their name.
     * @param versionStatus Which versions of the workflow to include in the response. Permission `workflow:list_filter` required, unless `developer_id` is provided and current user is developer, then only permission `workflow:list` required. Default `PUBLISHED` and `DEPRECATED`.
     * @param developerId Filter for workflow by developer. If current user is the developer, permission `workflow:list` required, otherwise `workflow:list_filter`.
     * @returns WorkflowOut Successful Response
     * @throws ApiError
     */
    public static workflowListWorkflows(
        nameSubstring?: string,
        versionStatus?: Array<WorkflowVersionStatus>,
        developerId?: string,
    ): CancelablePromise<Array<WorkflowOut>> {
        return __request(OpenAPI, {
            method: 'GET',
            url: '/workflows',
            query: {
                'name_substring': nameSubstring,
                'version_status': versionStatus,
                'developer_id': developerId,
            },
            errors: {
                400: `Error decoding JWT Token`,
                401: `Not Authenticated`,
                403: `Not Authorized`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }
    /**
     * List workflow OTRs
     * Get the ownership transfer requests for workflows.
     *
     * Permission `workflow:list` required if `current_owner_id` or `new_owner_id` is the current users id,
     * otherwise `workflow:list_all`
     * @param currentOwnerId UID of user who is the current owner.
     * @param newOwnerId UID of user who will be the new owner.
     * @returns OwnershipTransferRequestOut Successful Response
     * @throws ApiError
     */
    public static workflowListWorkflowOtrs(
        currentOwnerId?: string,
        newOwnerId?: string,
    ): CancelablePromise<Array<OwnershipTransferRequestOut>> {
        return __request(OpenAPI, {
            method: 'GET',
            url: '/workflows/ownership_transfer_request',
            query: {
                'current_owner_id': currentOwnerId,
                'new_owner_id': newOwnerId,
            },
            errors: {
                400: `Error decoding JWT Token`,
                401: `Not Authenticated`,
                403: `Not Authorized`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }
    /**
     * Get anonymized workflow execution
     * Get the workflow executions with meta information and anonymized user IDs.
     *
     * Permission `workflow:read` required if the `developer_id` is the same as the uid of the current user,
     * other `workflow:read_any`.
     * @param developerId Filter by the developer of the workflows
     * @param workflowId Filter by workflow IDs
     * @param start Filter by workflow executions after this date
     * @param end Filter by workflow executions before this date
     * @returns AnonymizedWorkflowExecution Successful Response
     * @throws ApiError
     */
    public static workflowGetDeveloperWorkflowStatistics(
        developerId?: string,
        workflowId?: Array<string>,
        start?: string,
        end?: string,
    ): CancelablePromise<Array<AnonymizedWorkflowExecution>> {
        return __request(OpenAPI, {
            method: 'GET',
            url: '/workflows/developer_statistics',
            query: {
                'developer_id': developerId,
                'workflow_id': workflowId,
                'start': start,
                'end': end,
            },
            errors: {
                400: `Error decoding JWT Token`,
                401: `Not Authenticated`,
                403: `Not Authorized`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }
    /**
     * Get a workflow
     * Get a specific workflow.
     *
     * Permission `workflow:read` required.
     * @param wid ID of a workflow
     * @param versionStatus Which versions of the workflow to include in the response. Permission `workflow:read_any` required if you are not the developer of this workflow. Default `PUBLISHED` and `DEPRECATED`
     * @returns WorkflowOut Successful Response
     * @throws ApiError
     */
    public static workflowGetWorkflow(
        wid: string,
        versionStatus?: Array<WorkflowVersionStatus>,
    ): CancelablePromise<WorkflowOut> {
        return __request(OpenAPI, {
            method: 'GET',
            url: '/workflows/{wid}',
            path: {
                'wid': wid,
            },
            query: {
                'version_status': versionStatus,
            },
            errors: {
                400: `Error decoding JWT Token`,
                401: `Not Authenticated`,
                403: `Not Authorized`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }
    /**
     * Delete a workflow
     * Delete a workflow.
     *
     * Permission `workflow:delete` required if the `developer_id` is the same as the uid of the current user,
     * other `workflow:delete_any`.
     * @param wid ID of a workflow
     * @returns void
     * @throws ApiError
     */
    public static workflowDeleteWorkflow(
        wid: string,
    ): CancelablePromise<void> {
        return __request(OpenAPI, {
            method: 'DELETE',
            url: '/workflows/{wid}',
            path: {
                'wid': wid,
            },
            errors: {
                400: `Error decoding JWT Token`,
                401: `Not Authenticated`,
                403: `Not Authorized`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }
    /**
     * Get a workflow OTR
     * Get a specific workflow ownership transfer request.
     *
     * Permission `workflow:read` required if current user is the current or new owner of the workflow,
     * otherwise `workflow:read_any` required.
     * @param wid ID of a workflow
     * @returns OwnershipTransferRequestOut Successful Response
     * @throws ApiError
     */
    public static workflowGetWorkflowOtr(
        wid: string,
    ): CancelablePromise<OwnershipTransferRequestOut> {
        return __request(OpenAPI, {
            method: 'GET',
            url: '/workflows/{wid}/ownership_transfer_request',
            path: {
                'wid': wid,
            },
            errors: {
                400: `Error decoding JWT Token`,
                401: `Not Authenticated`,
                403: `Not Authorized`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }
    /**
     * Create a workflow OTR
     * Create a ownership transfer request for a specific workflow.
     *
     * Permission `workflow:update` required if the current user is the current owner of the workflow,
     * otherwise `workflow:update_any` required.
     * @param wid ID of a workflow
     * @param requestBody
     * @returns OwnershipTransferRequestOut Successful Response
     * @throws ApiError
     */
    public static workflowCreateWorkflowOtr(
        wid: string,
        requestBody: OwnershipTransferRequestIn,
    ): CancelablePromise<OwnershipTransferRequestOut> {
        return __request(OpenAPI, {
            method: 'POST',
            url: '/workflows/{wid}/ownership_transfer_request',
            path: {
                'wid': wid,
            },
            body: requestBody,
            mediaType: 'application/json',
            errors: {
                400: `Error decoding JWT Token`,
                401: `Not Authenticated`,
                403: `Not Authorized`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }
    /**
     * Accept a workflow OTR
     * Accept an ownership transfer request for a specific workflow.
     *
     * Permission `workflow:update` required if the current user is the new owner of the workflow,
     * otherwise `workflow:update_any` required.
     * @param wid ID of a workflow
     * @returns WorkflowOut Successful Response
     * @throws ApiError
     */
    public static workflowAcceptWorkflowOtr(
        wid: string,
    ): CancelablePromise<WorkflowOut> {
        return __request(OpenAPI, {
            method: 'PATCH',
            url: '/workflows/{wid}/ownership_transfer_request',
            path: {
                'wid': wid,
            },
            errors: {
                400: `Error decoding JWT Token`,
                401: `Not Authenticated`,
                403: `Not Authorized`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }
    /**
     * Delete a workflow OTR
     * Delete/Reject a workflow ownership transfer request.
     *
     * Permission `workflow:update` required if current user is the current or new owner of the workflow,
     * otherwise `workflow:update_any` required.
     * @param wid ID of a workflow
     * @returns void
     * @throws ApiError
     */
    public static workflowDeleteWorkflowOtr(
        wid: string,
    ): CancelablePromise<void> {
        return __request(OpenAPI, {
            method: 'DELETE',
            url: '/workflows/{wid}/ownership_transfer_request',
            path: {
                'wid': wid,
            },
            errors: {
                400: `Error decoding JWT Token`,
                401: `Not Authenticated`,
                403: `Not Authorized`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }
    /**
     * Get statistics for a workflow
     * Get the number of started workflow per day.
     *
     * Permission `workflow:read` required.
     * @param wid ID of a workflow
     * @returns WorkflowStatistic Successful Response
     * @throws ApiError
     */
    public static workflowGetWorkflowStatistics(
        wid: string,
    ): CancelablePromise<Array<WorkflowStatistic>> {
        return __request(OpenAPI, {
            method: 'GET',
            url: '/workflows/{wid}/statistics',
            path: {
                'wid': wid,
            },
            errors: {
                400: `Error decoding JWT Token`,
                401: `Not Authenticated`,
                403: `Not Authorized`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }
    /**
     * Update a workflow
     * Create a new workflow version.
     *
     * Permission `workflow:update` required.
     * @param wid ID of a workflow
     * @param requestBody
     * @returns WorkflowVersion Successful Response
     * @throws ApiError
     */
    public static workflowUpdateWorkflow(
        wid: string,
        requestBody: WorkflowUpdate,
    ): CancelablePromise<WorkflowVersion> {
        return __request(OpenAPI, {
            method: 'POST',
            url: '/workflows/{wid}/update',
            path: {
                'wid': wid,
            },
            body: requestBody,
            mediaType: 'application/json',
            errors: {
                400: `Error decoding JWT Token`,
                401: `Not Authenticated`,
                403: `Not Authorized`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }
}
